FlutterBadgeManager class final
A Flutter plugin to manage app badges on Android, iOS and macOS.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → FlutterBadgeManager
-
Instance delegate (new style):
FlutterBadgeManager.instance.update(3).final