FlutterBadgeManagerPlatform class abstract
The interface that implementations of flutter_badge_manager must implement.
Platform implementations should extend this class
rather than implement it as flutter_badge_manager
does not consider newly added methods to be breaking changes.
Extending this class (using extends) ensures that the subclass
will get the default implementation, while platform implementations
that implements this interface will be broken
by newly added FlutterBadgeManagerPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- FlutterBadgeManagerPlatform
Constructors
- FlutterBadgeManagerPlatform()
- Constructs a FlutterBadgeManagerPlatform.
Properties
Methods
-
isSupported(
) → Future< bool> - Checks if the device supports app badges.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → Future< void> - Removes the app badge.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
int count) → Future< void> - Updates the app badge count.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterBadgeManagerPlatform
-
The current default FlutterBadgeManagerPlatform instance.
getter/setter pair