instance property
FlutterBadgeManagerPlatform
get
instance
The current default FlutterBadgeManagerPlatform instance.
Federated platform packages replace this with their own Pigeon-backed implementations during registration.
Implementation
static FlutterBadgeManagerPlatform get instance =>
_instance ??= _MissingFlutterBadgeManagerPlatform.instance;
set
instance
(FlutterBadgeManagerPlatform instance)
Platform-specific plugins should set this with their own platform-specific class that extends FlutterBadgeManagerPlatform when they register themselves.
Implementation
static set instance(FlutterBadgeManagerPlatform instance) {
if (!instance.isMock) PlatformInterface.verify(instance, _token);
_instance = instance;
}